summaryrefslogtreecommitdiffstats
path: root/chrome/browser/extensions/extension_icon_image.h
diff options
context:
space:
mode:
authorjamescook@chromium.org <jamescook@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-10-25 00:41:28 +0000
committerjamescook@chromium.org <jamescook@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-10-25 00:41:28 +0000
commit472522b6f4e3fcee5645b672015c031801a3ff19 (patch)
tree12b46604f730dd853a3a9917b27b08a3baaafa5b /chrome/browser/extensions/extension_icon_image.h
parentd569a3eac706ccbc18a52e3dc8451d922e30f849 (diff)
downloadchromium_src-472522b6f4e3fcee5645b672015c031801a3ff19.zip
chromium_src-472522b6f4e3fcee5645b672015c031801a3ff19.tar.gz
chromium_src-472522b6f4e3fcee5645b672015c031801a3ff19.tar.bz2
Move extensions::ImageLoader and IconImage to BrowserContext
BUG=309909 TEST=unit_tests TBR=rohitrao@chromium.org for trivial include change in c/b/ui/cocoa/infobars Review URL: https://codereview.chromium.org/38113003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@230880 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/extensions/extension_icon_image.h')
-rw-r--r--chrome/browser/extensions/extension_icon_image.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/chrome/browser/extensions/extension_icon_image.h b/chrome/browser/extensions/extension_icon_image.h
index 94cdae5..b6fc0c4 100644
--- a/chrome/browser/extensions/extension_icon_image.h
+++ b/chrome/browser/extensions/extension_icon_image.h
@@ -16,7 +16,9 @@
#include "ui/base/layout.h"
#include "ui/gfx/image/image_skia.h"
-class Profile;
+namespace content {
+class BrowserContext;
+}
namespace extensions {
class Extension;
@@ -58,10 +60,10 @@ class IconImage : public content::NotificationObserver {
virtual ~Observer() {}
};
// |profile| is required by the underlying implementation to retrieve the
// |ImageLoader| instance associated with the given profile. |ImageLoader| is
// used to perform the asynchronous image load work.
- IconImage(Profile* profile,
+ IconImage(content::BrowserContext* context,
const Extension* extension,
const ExtensionIconSet& icon_set,
int resource_size_in_dip,
@@ -89,7 +91,7 @@ class IconImage : public content::NotificationObserver {
const content::NotificationSource& source,
const content::NotificationDetails& details) OVERRIDE;
- Profile* profile_;
+ content::BrowserContext* browser_context_;
const Extension* extension_;
const ExtensionIconSet& icon_set_;
const int resource_size_in_dip_;
@@ -58,10 +60,10 @@ class IconImage : public content::NotificationObserver {
virtual ~Observer() {}
};
- // |profile| is required by the underlying implementation to retrieve the
- // |ImageLoader| instance associated with the given profile. |ImageLoader| is
+ // |context| is required by the underlying implementation to retrieve the
+ // |ImageLoader| instance associated with the given context. |ImageLoader| is
// used to perform the asynchronous image load work.